@@ -67,6 +67,10 @@ class Drive(NetBoxModel):
     def physicalvolumes_in_drive_count(self):
         return PhysicalVolume.objects.filter(drive=self).count()
 
+    def left_free_space(self):
+        current_partition_allocated_space = Partition.objects.filter(drive=self).aggregate(sum=Sum("size")).get("sum") or 0
+        return self.size - current_partition_allocated_space
+
 
 class Partition(NetBoxModel):
     drive = models.ForeignKey(
@@ -107,6 +111,12 @@ class Partition(NetBoxModel):
         total_allocated_space = Partition.objects.filter(drive=self.drive).aggregate(sum=Sum("size")).get("sum") or 0
         current_partition_size = Partition.objects.filter(drive=self.drive, id=self.pk)\
             .aggregate(sum=Sum("size")).get("sum") or 0
+        if self.size is None:
+            raise ValidationError(
+                {
+                    "size": f"The Value for Size must be greater than 0"
+                }
+            )
         diff_to_allocated_space = self.size - current_partition_size
         if diff_to_allocated_space > 0:
             if total_allocated_space == self.drive.size:
