@@ -6,10 +6,11 @@ from netbox_storage.models import Drive, Partition, PhysicalVolume, LogicalVolum
 
 
 class LVMModel:
-    def __init__(self, lv_name, path, fs, vg_name, pv_list, partition_list, drive_list):
+    def __init__(self, lv_name, path, fs, size, vg_name, pv_list=None, partition_list=None, drive_list=None):
         self.lv_name = lv_name
         self.path = path
         self.fs = fs
+        self.size = size
         self.vg_name = vg_name
         self.pv_list = pv_list
         self.partition_list = partition_list
@@ -25,11 +26,12 @@ class RelatedDrives(PluginTemplateExtension):
         # --- Try via Logical Volume
         lvs = LogicalVolume.objects.all()
         lvm_list = []
+        logger = logging.getLogger('netbox.plugins.netbox_storage')
 
         # appending instances to list
         for lv in lvs:
-            vg = VolumeGroup.objects.get(lv.vg)
-            lvm_list.append(LVMModel(lv.lv_name, lv.path, lv.fs, vg.name))
+            logger.warning(f'{lv.vg}')
+            lvm_list.append(LVMModel(lv.lv_name, lv.path, lv.fs, lv.size, lv.vg.vg_name))
             # physical_volumes = PhysicalVolume.objects.all()
             # physical_volume_list = []
             # for physical_volume in physical_volumes:
